translate.storage.xml_extract.extract.ParseState

Package translate :: Package storage :: Package xml_extract :: Module extract :: Class ParseState |
[hide private]
[frames] | no frames]

# Class ParseState

source code

Maintain constants and variables used during the walking of a DOM tree (via the function apply).

Instance Methods | [hide private]
__init__(self, no_translate_content_elements, inline_elements=`{``}`, nsmap=`{``}`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, no_translate_content_elements, inline_elements=`{``}`, nsmap=`{``}`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)